import System.Environment
import Text.CSL.Test

-- a dir with a final slash
testDir = "citeproc-test/processor-tests/machines/"

main :: IO ()
main = do
  args <- getArgs
  runTS args 0 testDir
